diff --git a/sen2chain/library.py b/sen2chain/library.py
index db3795a853d7cc61ee45a677f5563bea07f1d411..4aaaf15304d20511f2a0e00a3c1369c4cf46034c 100644
--- a/sen2chain/library.py
+++ b/sen2chain/library.py
@@ -122,7 +122,7 @@ class Library:
             pass
     
     def archive_l2a(self,
-                    archive_list: list = [],
+                    tile_list: list = [],
                     size_only: bool = False,
                     ):
                         
@@ -130,14 +130,14 @@ class Library:
         Function to archive l2a products from library folder to l2a_archive_path.
         Calls the archive_l2a function from Tile class, see there for details.
         
         :param archive_list: list of tiles to archive. If not provided, will process all l2a tiles.
         :param size_only: if True, only gives sizes
         """        
         
         total_size = 0 
-        if not archive_list:
-            archive_list = self.l2a
-        for t in archive_list:
+        if not tile_list:
+            tile_list = self.l2a
+        for t in tile_list:
             try:
                 logger.info(t)
                 til = Tile(t)
@@ -130,14 +130,14 @@ class Library:
         Calls the archive_l2a function from Tile class, see there for details.
         
-        :param archive_list: list of tiles to archive. If not provided, will process all l2a tiles.
+        :param tile_list: list of tiles to archive. If not provided, will process all l2a tiles.
         :param size_only: if True, only gives sizes
         """        